@@ -20,13 +20,21 @@ sub reschedule
 
     while (my($netloc, $server) = each %{$ua->{servers}}) {
 	my($req,$conn,$iconn, $max_conn) = $server->c_status;
+	if ($req && $conn) {
+	    # Let's see if any of the existing connections can
+	    # absorb the request queue.
+	    print STDERR "$netloc->activate_connections\n" if $DEBUG;
+	    $server->activate_connections;
+	    ($req,$conn,$iconn, $max_conn) = $server->c_status;
+	}
 
 	# Calculate how many connections we would like to start for
 	# this server
 	my $sconn = $req - $conn;       # one connection per request
+	my $max_start = $max_conn - $conn;
+	$sconn = $max_start if $max_conn && $sconn > $max_start;
 	$sconn = 0 if $sconn < 0;
-	$sconn = $max_conn if $max_conn && $sconn > $max_conn;
-	print "SCHED $netloc $req $conn $iconn ($max_conn) $sconn\n"
+	print STDERR "SCHED $netloc R=$req C=$conn I=$iconn ($max_conn) S=$sconn\n"
 	    if $DEBUG;
 
 	$gconn  += $conn;
@@ -42,6 +50,7 @@ sub reschedule
 	for (@start) {
 	    my($no, $server) = @$_;
 	    for (1..$no) {
+		print STDERR $server->id, "->create_connection\n" if $DEBUG;
 		$server->create_connection;
 	    }
 	}
@@ -54,16 +63,18 @@ sub reschedule
 	# we have reached global limit, but have idle connections that
 	# we can kill off first
 	my($no, $server) = @{ shift(@idle) };
+	print STDERR $server->id, "->stop_idle\n" if $DEBUG;
 	$server->stop_idle;
 	$gconn -= $no;
     }
 
-    # Start servers until we reach limit.  The problem with this
-    # approach is that some servers can starve (XXX).
+    # Start server connections until we reach limit.
+    # XXX the problem with this approach is that some servers can starve.
   START_UP:
     for (@start) {
 	my($no, $server) = @$_;
 	for (1..$no) {
+	    print STDERR $server->id, "->create_connection\n" if $DEBUG;
 	    $server->create_connection;
 	    last START_UP if ++$gconn >= $conn_limit;
 	}
